@@ -5,26 +5,6 @@
 #endif
 #undef _AGAR_AU_BEGIN_H_
 
-/*
- * Undo standard definitions from begin.h, unless we are compiling the
- * library itself.
- */
-#ifndef _AGAR_AU_INTERNAL
-# include <agar/core/close_types.h>
-# ifdef _AGAR_AU_DEFINED_CDECLS
-#  undef _AGAR_AU_DEFINED_CDECLS
-#  undef __BEGIN_DECLS
-#  undef __END_DECLS
-# endif
-# ifdef _AGAR_AU_DEFINED_NLS
-#  undef _
-#  undef N_
-#  undef ngettext
-# endif
-#endif /* _AGAR_AU_INTERNAL */
-
-#undef _AGAR_AU_USE_INLINE
-
 /* Reset structure packing at previous byte alignment. */
 #if defined(_MSC_VER) || defined(__MWERKS__) || defined(__WATCOMC__) || defined(__BORLANDC__)
 # ifdef __BORLANDC__
@@ -38,14 +18,41 @@
 # endif
 #endif
 
-/* Always undo DECLSPEC and NULL. */
-#ifdef _AGAR_AU_DEFINED_DECLSPEC
-# undef _AGAR_AU_DEFINED_DECLSPEC
-# undef DECLSPEC
-#endif
-#ifdef _AGAR_AU_DEFINED_NULL
-# undef _AGAR_AU_DEFINED_NULL
-# undef NULL
-#endif
+#undef _AGAR_AU_USE_INLINE
+
+#ifndef _AGAR_AU_INTERNAL
+/* Primitive types */
+# include <agar/core/close_types.h>
+/* Declarations */
+# ifdef _AGAR_AU_DEFINED_CDECLS
+#  undef _AGAR_AU_DEFINED_CDECLS
+#  undef __BEGIN_DECLS
+#  undef __END_DECLS
+# endif
+# ifdef _AGAR_AU_DEFINED_DECLSPEC
+#  undef _AGAR_AU_DEFINED_DECLSPEC
+#  undef DECLSPEC
+# endif
+/* NLS */
+# ifdef _AGAR_AU_DEFINED_NLS
+#  undef _
+#  undef N_
+#  undef ngettext
+# endif
+/* Nullability */
+# ifdef _AGAR_AU_DEFINED_NULL
+#  undef _AGAR_AU_DEFINED_NULL
+#  undef NULL
+# endif
+# if defined(_AGAR_AU_DEFINED_NULLABILITY) && !defined(_USE_AGAR_NULLABILITY)
+#  undef _Nonnull
+#  undef _Nullable
+#  undef _Null_unspecified
+# endif
+/* Restrict */
+# ifdef _AGAR_AU_DEFINED_RESTRICT
+#  undef _Restrict
+# endif
+#endif /* _AGAR_AU_INTERNAL */
 
 #include <agar/core/close_attributes.h>
