@@ -13,12 +13,11 @@ typedef struct ag_dbobject {
 /* Begin generated block */
 __BEGIN_DECLS
 extern DECLSPEC AG_ObjectClass agDbObjectClass;
-extern DECLSPEC AG_DbObject *AG_DbObjectNew(void);
-extern DECLSPEC AG_List *AG_DbObjectList(AG_Db *);
-extern DECLSPEC int AG_DbObjectLoad(void *, AG_Db *, const char *);
-extern DECLSPEC int AG_DbObjectSave(void *, AG_Db *);
-extern DECLSPEC int AG_DbObjectInsert(AG_Db *, void *);
-extern DECLSPEC int AG_DbObjectDelete(AG_Db *, const char *);
+extern DECLSPEC AG_DbObject *_Nullable AG_DbObjectNew(void);
+extern DECLSPEC int AG_DbObjectLoad(void *_Nonnull, AG_Db *_Nonnull, const char *_Nonnull);
+extern DECLSPEC int AG_DbObjectSave(void *_Nonnull, AG_Db *_Nonnull);
+extern DECLSPEC int AG_DbObjectInsert(AG_Db *_Nonnull, void *_Nonnull);
+extern DECLSPEC int AG_DbObjectDelete(AG_Db *_Nonnull, const char *_Nonnull);
 __END_DECLS
 /* Close generated block */
 
