@@ -4,8 +4,9 @@
 #define _AGAR_CORE_EXEC_H_
 #include <agar/core/begin.h>
 
-#include <agar/config/have_execvp.h>
+#ifdef AG_ENABLE_EXEC
 
+#include <agar/config/have_execvp.h>
 #if defined(HAVE_EXECVP) && !defined(_WIN32)
 # include <unistd.h>
 # include <sys/types.h>
@@ -25,11 +26,12 @@ typedef int AG_ProcessID;
 
 /* Begin generated block */
 __BEGIN_DECLS
-extern DECLSPEC AG_ProcessID AG_Execute(const char *, char **);
+extern DECLSPEC AG_ProcessID AG_Execute(const char *_Nullable, char *_Nullable *_Nullable);
 extern DECLSPEC AG_ProcessID AG_WaitOnProcess(AG_ProcessID, enum ag_exec_wait_type);
 extern DECLSPEC int AG_Kill(AG_ProcessID);
 __END_DECLS
 /* Close generated block */
 
+#endif /* AG_ENABLE_EXEC */
 #include <agar/core/close.h>
 #endif /* _AGAR_CORE_EXEC_H_ */
