@@ -2,6 +2,10 @@
 
 #ifndef _AGAR_CORE_FILE_H_
 #define _AGAR_CORE_FILE_H_
+
+#include <agar/config/ag_serialization.h>
+#ifdef AG_SERIALIZATION
+
 #include <agar/core/begin.h>
 
 enum ag_file_info_type {
@@ -26,27 +30,30 @@ typedef struct ag_file_info {
 #define AG_FILE_HIDDEN		0x020
 #define AG_FILE_TEMPORARY	0x100
 #define AG_FILE_SYSTEM		0x200
+	Uint32 _pad;
 } AG_FileInfo;
 
 typedef struct ag_file_ext_mapping {
-	const char *ext;			/* Extension */
-	const char *descr;			/* Type description */
-	void *cls;				/* Related Agar class */
+	const char *_Nonnull ext;		/* Extension */
+	const char *_Nonnull descr;		/* Type description */
+	void *_Nullable cls;			/* Related Agar class */
 	int editDirect;				/* Directly editable */
+	Uint32 _pad;
 } AG_FileExtMapping;
 
 /* Begin generated block */
 __BEGIN_DECLS
-extern DECLSPEC AG_FileExtMapping *agFileExtMap;
+extern DECLSPEC AG_FileExtMapping *_Nullable agFileExtMap;
 extern DECLSPEC Uint agFileExtCount;
-extern DECLSPEC int AG_GetFileInfo(const char *, AG_FileInfo *);
-extern DECLSPEC int AG_GetSystemTempDir(char *, size_t) BOUNDED_ATTRIBUTE(__string__, 1, 2);
-extern DECLSPEC int AG_FileExists(const char *);
-extern DECLSPEC int AG_FileDelete(const char *);
-extern DECLSPEC const char *AG_ShortFilename(const char *);
-extern DECLSPEC void AG_RegisterFileExtMappings(const AG_FileExtMapping *, Uint);
+extern DECLSPEC int AG_GetFileInfo(const char *_Nonnull, AG_FileInfo *_Nonnull);
+extern DECLSPEC int AG_GetSystemTempDir(char *_Nonnull, AG_Size);
+extern DECLSPEC int AG_FileExists(const char *_Nonnull);
+extern DECLSPEC int AG_FileDelete(const char *_Nonnull);
+extern DECLSPEC const char *_Nonnull AG_ShortFilename(const char *_Nonnull);
+extern DECLSPEC void AG_RegisterFileExtMappings(const AG_FileExtMapping *_Nonnull, Uint);
 __END_DECLS
 /* Close generated block */
 
 #include <agar/core/close.h>
+#endif /* AG_SERIALIZATION */
 #endif /* _AGAR_CORE_FILE_H_ */
