@@ -3,7 +3,7 @@
 #include <agar/core/begin.h>
 /* Begin generated block */
 __BEGIN_DECLS
-extern DECLSPEC int AG_Getopt(int, char * const [], const char *, char **, int *);
+extern DECLSPEC int AG_Getopt(int, char *_Nonnull const [_Nonnull], const char *_Nonnull, char *_Nullable *_Nonnull, int *_Nullable);
 __END_DECLS
 /* Close generated block */
 #include <agar/core/close.h>
