@@ -5,14 +5,15 @@
 #include <agar/core/begin.h>
 
 #define AGAR_MAJOR_VERSION	1
-#define AGAR_MINOR_VERSION	5
+#define AGAR_MINOR_VERSION	6
 #define AGAR_PATCHLEVEL		0
 
 typedef struct ag_agar_version {
-	int major;
-	int minor;
-	int patch;
-	const char *release;
+	int major;			/* Major version number */
+	int minor;			/* Minor version number */
+	int patch;			/* Patchlevel */
+	int rev;			/* SVN revision number (or 0) */
+	const char *_Nullable release;
 } AG_AgarVersion;
 
 #define AG_VERSION_NUM(X,Y,Z) ((X)*1000 + (Y)*100 + (Z))
@@ -21,7 +22,7 @@ typedef struct ag_agar_version {
 
 /* Begin generated block */
 __BEGIN_DECLS
-extern DECLSPEC void AG_GetVersion(AG_AgarVersion *);
+extern DECLSPEC void AG_GetVersion(AG_AgarVersion *_Nonnull);
 __END_DECLS
 /* Close generated block */
 
