@@ -6,10 +6,10 @@
 
 typedef struct ag_input_device {
 	struct ag_object _inherit;
+	void *_Nullable drv;	/* Associated graphics driver */
+	char *_Nullable desc;	/* User description */
 	Uint flags;
-	void *drv;		/* Associated graphics driver */
-	char *desc;		/* User description */
-	AG_EventQ events;	/* Queue of input events */
+	Uint32 _pad;
 } AG_InputDevice;
 
 #define AGINPUTDEV(obj) ((AG_InputDevice *)(obj))
@@ -18,7 +18,6 @@ typedef struct ag_input_device {
 __BEGIN_DECLS
 extern DECLSPEC AG_ObjectClass agInputDeviceClass;
 extern DECLSPEC AG_Object agInputDevices; 
-extern DECLSPEC AG_InputDevice *AG_InputDeviceNew(void *);
 __END_DECLS
 /* Close generated block */
 
