@@ -3,7 +3,7 @@
 #include <agar/gui/begin.h>
 /* Begin generated block */
 __BEGIN_DECLS
-extern DECLSPEC int AG_XCFLoad(AG_DataSource *, off_t, void (*)(AG_Surface *, const char *, void *), void *);
+extern DECLSPEC int AG_XCFLoad(AG_DataSource *_Nonnull, AG_Offset, void (*_Nonnull)(AG_Surface *_Nonnull, const char *_Nonnull, void *_Nullable), void *_Nullable);
 __END_DECLS
 /* Close generated block */
 #include <agar/gui/close.h>
