@@ -2,10 +2,10 @@
 
 /* Begin generated block */
 __BEGIN_DECLS
-extern DECLSPEC M_Rectangle2 M_RectangleRead2(AG_DataSource *);
-extern DECLSPEC M_Rectangle3 M_RectangleRead3(AG_DataSource *);
-extern DECLSPEC void M_RectangleWrite2(AG_DataSource *, M_Rectangle2 *);
-extern DECLSPEC void M_RectangleWrite3(AG_DataSource *, M_Rectangle3 *);
+extern DECLSPEC M_Rectangle2 M_RectangleRead2(AG_DataSource *_Nonnull);
+extern DECLSPEC M_Rectangle3 M_RectangleRead3(AG_DataSource *_Nonnull);
+extern DECLSPEC void M_RectangleWrite2(AG_DataSource *_Nonnull, M_Rectangle2 *_Nonnull);
+extern DECLSPEC void M_RectangleWrite3(AG_DataSource *_Nonnull, M_Rectangle3 *_Nonnull);
 extern DECLSPEC int M_PointInRectangle2(M_Rectangle2, M_Vector2);
 
 static __inline__ M_Rectangle2
@@ -37,7 +37,7 @@ M_RectangleWidth3(M_Rectangle3 R)
 }
 
 static __inline__ M_Real
-M_RectangleWidth3v(const M_Rectangle3 *R)
+M_RectangleWidth3v(const M_Rectangle3 *_Nonnull R)
 {
 	return M_VecDistance3(R->b, R->c);
 }
@@ -49,7 +49,7 @@ M_RectangleHeight3(M_Rectangle3 R)
 }
 
 static __inline__ M_Real
-M_RectangleHeight3v(const M_Rectangle3 *R)
+M_RectangleHeight3v(const M_Rectangle3 *_Nonnull R)
 {
 	return M_VecDistance3(R->a, R->b);
 }
