@@ -687,6 +687,7 @@ typedef struct AllocationRecord *AllocationListPtr;
 struct FillinListNodeStruct
 {   ElementPtr  pFillinList;
     int         NumberOfFillinsInList;
+    Uint32 _pad;
     struct      FillinListNodeStruct  *Next;
 };
 
@@ -891,6 +892,7 @@ struct  MatrixFrame
     int                          Elements;
     int                          Error;
     int                          ExtSize;
+    Uint32 _pad1;
     int                         *ExtToIntColMap;
     int                         *ExtToIntRowMap;
     BOOLEAN                      Factored;
@@ -900,6 +902,7 @@ struct  MatrixFrame
     unsigned long                ID;
     RealVector                   Intermediate;
     BOOLEAN                      InternalVectorsAllocated;
+    Uint32 _pad2;
     int                         *IntToExtColMap;
     int                         *IntToExtRowMap;
     int                         *MarkowitzRow;
@@ -912,6 +915,7 @@ struct  MatrixFrame
     int                          PivotsOriginalCol;
     int                          PivotsOriginalRow;
     char                         PivotSelectionMethod;
+    Uint8 _pad3[3];
     BOOLEAN                      PreviousMatrixWasComplex;
     RealNumber                   RelThreshold;
     BOOLEAN                      Reordered;
@@ -924,10 +928,13 @@ struct  MatrixFrame
 
     AllocationListPtr            TopOfAllocationList;
     int                          RecordsRemaining;
+    Uint32 _pad4;
     ElementPtr                   NextAvailElement;
     int                          ElementsRemaining;
+    Uint32 _pad5;
     ElementPtr                   NextAvailFillin;
     int                          FillinsRemaining;
+    Uint32 _pad6;
     struct FillinListNodeStruct *FirstFillinListNode;
     struct FillinListNodeStruct *LastFillinListNode;
 };
