@@ -4,10 +4,10 @@
 __BEGIN_DECLS
 extern DECLSPEC M_Triangle2 M_TriangleFromLines2(M_Line2, M_Line2, M_Line2);
 extern DECLSPEC M_Triangle3 M_TriangleFromLines3(M_Line3, M_Line3, M_Line3);
-extern DECLSPEC M_Triangle2 M_TriangleRead2(AG_DataSource *);
-extern DECLSPEC M_Triangle3 M_TriangleRead3(AG_DataSource *);
-extern DECLSPEC void M_TriangleWrite2(AG_DataSource *, M_Triangle2 *);
-extern DECLSPEC void M_TriangleWrite3(AG_DataSource *, M_Triangle3 *);
+extern DECLSPEC M_Triangle2 M_TriangleRead2(AG_DataSource *_Nonnull);
+extern DECLSPEC M_Triangle3 M_TriangleRead3(AG_DataSource *_Nonnull);
+extern DECLSPEC void M_TriangleWrite2(AG_DataSource *_Nonnull, M_Triangle2 *_Nonnull);
+extern DECLSPEC void M_TriangleWrite3(AG_DataSource *_Nonnull, M_Triangle3 *_Nonnull);
 extern DECLSPEC int M_PointInTriangle2(M_Triangle2, M_Vector2);
 
 static __inline__ M_Triangle2
