@@ -3,15 +3,18 @@
 #ifndef _AGAR_VG_PUBLIC_H_
 #define _AGAR_VG_PUBLIC_H_
 #define _AGAR_VG_PUBLIC
-#include <agar/core/core_begin.h>
+
+#include <agar/core/core.h>
+
 #include <agar/gui/window.h>
 #include <agar/gui/button.h>
 #include <agar/gui/iconmgr.h>
+
 #include <agar/vg/vg.h>
 #include <agar/vg/vg_tool.h>
 #include <agar/vg/vg_view.h>
 #include <agar/vg/vg_math.h>
 #include <agar/vg/icons.h>
 #include <agar/vg/vg_tools.h>
-#include <agar/core/core_close.h>
-#endif
+
+#endif /* !_AGAR_VG_PUBLIC_H_ */
